@@ -16,7 +16,7 @@
 class GeneratorsTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void testLoadsCorrectly();
 };
 
@@ -40,7 +40,7 @@ void GeneratorsTest::testLoadsCorrectly()
     }
     int failures = 0;
     int successful = 0;
-    foreach (const QString &lib, generatorLibs) {
+    for (const QString &lib : qAsConst(generatorLibs)) {
         KPluginLoader loader(lib);
         QVERIFY2(!loader.fileName().isEmpty(), qPrintable(lib));
         qDebug() << loader.fileName();
