@@ -50,8 +50,9 @@ static void docSetPageNum(KJSContext *ctx, void *object, KJSObject value)
 
     int page = value.toInt32(ctx);
 
-    if (page == (int)doc->m_parent->currentPage())
+    if (page == (int)doc->m_parent->currentPage()) {
         return;
+    }
 
     doc->m_parent->setViewportPage(page);
 }
@@ -189,11 +190,10 @@ static KJSObject docGetField(KJSContext *context, void *object, const KJSArgumen
 
     QVector<Page *>::const_iterator pIt = doc->m_pagesVector.constBegin(), pEnd = doc->m_pagesVector.constEnd();
     for (; pIt != pEnd; ++pIt) {
-        const QLinkedList<Okular::FormField *> pageFields = (*pIt)->formFields();
-        QLinkedList<Okular::FormField *>::const_iterator ffIt = pageFields.constBegin(), ffEnd = pageFields.constEnd();
-        for (; ffIt != ffEnd; ++ffIt) {
-            if ((*ffIt)->fullyQualifiedName() == cName) {
-                return JSField::wrapField(context, *ffIt, *pIt);
+        const QList<Okular::FormField *> pageFields = (*pIt)->formFields();
+        for (FormField *form : pageFields) {
+            if (form->fullyQualifiedName() == cName) {
+                return JSField::wrapField(context, form, *pIt);
             }
         }
     }
@@ -226,8 +226,9 @@ static KJSObject docGotoNamedDest(KJSContext *ctx, void *object, const KJSArgume
     QString dest = arguments.at(0).toString(ctx);
 
     DocumentViewport viewport(doc->m_generator->metaData(QStringLiteral("NamedViewport"), dest).toString());
-    if (!viewport.isValid())
+    if (!viewport.isValid()) {
         return KJSUndefined();
+    }
 
     doc->m_parent->setViewport(viewport);
 
@@ -248,12 +249,12 @@ static KJSObject docGetNthFieldName(KJSContext *ctx, void *object, const KJSArgu
     int numField = arguments.at(0).toInt32(ctx);
 
     for (const Page *pIt : qAsConst(doc->m_pagesVector)) {
-        const QLinkedList<Okular::FormField *> pageFields = pIt->formFields();
+        const QList<Okular::FormField *> pageFields = pIt->formFields();
 
         if (numField < pageFields.size()) {
-            const auto ffIt = pageFields.begin() + numField;
+            const Okular::FormField *form = pageFields[numField];
 
-            return KJSString((*ffIt)->fullyQualifiedName());
+            return KJSString(form->fullyQualifiedName());
         }
 
         numField -= pageFields.size();
@@ -290,8 +291,9 @@ void JSDocument::initType(KJSContext *ctx)
     assert(g_docProto);
 
     static bool initialized = false;
-    if (initialized)
+    if (initialized) {
         return;
+    }
     initialized = true;
 
     g_docProto->defineProperty(ctx, QStringLiteral("numPages"), docGetNumPages);
@@ -325,7 +327,8 @@ void JSDocument::initType(KJSContext *ctx)
 
 KJSGlobalObject JSDocument::wrapDocument(DocumentPrivate *doc)
 {
-    if (!g_docProto)
+    if (!g_docProto) {
         g_docProto = new KJSPrototype();
+    }
     return g_docProto->constructGlobalObject(doc);
 }
