@@ -44,7 +44,7 @@ public:
         @param pg number of the page
         @param _distance_from_top distance from the top of the page
     */
-    Anchor(const PageNumber pg, const Length _distance_from_top)
+    Anchor(quint16 pg, const Length _distance_from_top)
         : page(pg)
         , distance_from_top(_distance_from_top)
     {
