@@ -10,6 +10,7 @@
 
 #include "core/action.h"
 
+#include "generator_pdf.h"
 #include "pdfsettings.h"
 #include "pdfsignatureutils.h"
 
@@ -267,7 +268,7 @@ PopplerFormFieldChoice::PopplerFormFieldChoice(std::unique_ptr<Poppler::FormFiel
     m_id = m_field->id();
     SET_ACTIONS
 
-#ifdef HAVE_POPPLER_0_87
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(0, 87, 0)
     QMap<QString, QString> values;
     const auto fieldChoicesWithExportValues = m_field->choicesWithExportValues();
     for (const QPair<QString, QString> &value : fieldChoicesWithExportValues) {
@@ -395,7 +396,7 @@ PopplerFormFieldSignature::PopplerFormFieldSignature(std::unique_ptr<Poppler::Fo
     m_rect = Okular::NormalizedRect::fromQRectF(m_field->rect());
     m_id = m_field->id();
     int validateOptions = Poppler::FormFieldSignature::ValidateVerifyCertificate;
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
     if (!PDFSettings::checkOCSPServers()) {
         validateOptions = validateOptions | Poppler::FormFieldSignature::ValidateWithoutOCSPRevocationCheck;
     }
@@ -453,6 +454,10 @@ PopplerFormFieldSignature::SignatureType PopplerFormFieldSignature::signatureTyp
         return Okular::FormFieldSignature::AdbePkcs7detached;
     case Poppler::FormFieldSignature::EtsiCAdESdetached:
         return Okular::FormFieldSignature::EtsiCAdESdetached;
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(22, 2, 0)
+    case Poppler::FormFieldSignature::UnsignedSignature:
+        return Okular::FormFieldSignature::UnsignedSignature;
+#endif
     default:
         return Okular::FormFieldSignature::UnknownType;
     }
@@ -462,3 +467,16 @@ const Okular::SignatureInfo &PopplerFormFieldSignature::signatureInfo() const
 {
     return *m_info;
 }
+
+bool PopplerFormFieldSignature::sign(const Okular::NewSignatureData &oData, const QString &newPath) const
+{
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(22, 2, 0)
+    Poppler::PDFConverter::NewSignatureData pData;
+    PDFGenerator::okularToPoppler(oData, &pData);
+    return m_field->sign(newPath, pData) == Poppler::FormFieldSignature::SigningSuccess;
+#else
+    Q_UNUSED(oData)
+    Q_UNUSED(newPath)
+    return false;
+#endif
+}
