@@ -51,8 +51,6 @@
 
 #include "pdfsettings.h"
 
-#include <config-okular-poppler.h>
-
 #include <poppler-media.h>
 #include <poppler-version.h>
 
@@ -380,7 +378,7 @@ static Okular::DocumentAction::DocumentActionType popplerToOkular(Poppler::LinkA
         return Okular::DocumentAction::Close;
     case Poppler::LinkAction::Print:
         return Okular::DocumentAction::Print;
-#ifdef HAVE_POPPLER_22_04
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(22, 04, 0)
     case Poppler::LinkAction::SaveAs:
         return Okular::DocumentAction::SaveAs;
 #endif
@@ -567,9 +565,9 @@ Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool
 /**
  * Note: the function will take ownership of the popplerLink objects.
  */
-static QLinkedList<Okular::ObjectRect *> generateLinks(const QList<Poppler::Link *> &popplerLinks)
+static QList<Okular::ObjectRect *> generateLinks(const QList<Poppler::Link *> &popplerLinks)
 {
-    QLinkedList<Okular::ObjectRect *> links;
+    QList<Okular::ObjectRect *> links;
     for (const Poppler::Link *popplerLink : popplerLinks) {
         QRectF linkArea = popplerLink->linkArea();
         double nl = linkArea.left(), nt = linkArea.top(), nr = linkArea.right(), nb = linkArea.bottom();
@@ -633,7 +631,7 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
     // You only need to do it once not for each of the documents but it is cheap enough
     // so doing it all the time won't hurt either
     Poppler::setDebugErrorFunction(PDFGeneratorPopplerDebugFunction, QVariant());
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     if (!PDFSettings::useDefaultCertDB()) {
         Poppler::setNSSDir(QUrl(PDFSettings::dBCertificatePath()).toLocalFile());
     }
@@ -694,7 +692,7 @@ Okular::Document::OpenResult PDFGenerator::init(QVector<Okular::Page *> &pagesVe
     }
 
     xrefReconstructed = false;
-#ifdef HAVE_POPPLER_RECONSTRUCTION_CALLBACK
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 6, 0)
     if (pdfdoc->xrefWasReconstructed()) {
         xrefReconstructionHandler();
     } else {
@@ -825,7 +823,7 @@ void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation,
             page->setDuration(p->duration());
             page->setLabel(p->label());
 
-            QLinkedList<Okular::FormField *> okularFormFields;
+            QList<Okular::FormField *> okularFormFields;
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(0, 89, 0)
             if (i > 0) { // for page 0 we handle the form fields at the end
                 okularFormFields = getFormFields(p);
@@ -859,7 +857,7 @@ void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation,
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(0, 89, 0)
         const QVector<Poppler::FormFieldSignature *> allSignatures = pdfdoc->signatures();
         std::unique_ptr<Poppler::Page> page0(pdfdoc->page(0));
-        QLinkedList<Okular::FormField *> page0FormFields = getFormFields(page0.get());
+        QList<Okular::FormField *> page0FormFields = getFormFields(page0.get());
 
         for (Poppler::FormFieldSignature *s : allSignatures) {
             bool createSignature = true;
@@ -868,7 +866,7 @@ void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation,
 
             // See if the signature is in one of the already loaded page (i.e. 1 to end)
             for (Okular::Page *p : qAsConst(pagesVector)) {
-                const QLinkedList<Okular::FormField *> pageFormFields = p->formFields();
+                const QList<Okular::FormField *> pageFormFields = p->formFields();
                 if (std::find_if(pageFormFields.begin(), pageFormFields.end(), compareSignatureByFullyQualifiedName) != pageFormFields.end()) {
                     delete s;
                     createSignature = false;
@@ -1281,7 +1279,7 @@ void PDFGenerator::resolveMediaLinkReferences(Okular::Page *page)
     resolveMediaLinkReference(const_cast<Okular::Action *>(page->pageAction(Okular::Page::Opening)));
     resolveMediaLinkReference(const_cast<Okular::Action *>(page->pageAction(Okular::Page::Closing)));
 
-    const QLinkedList<Okular::Annotation *> annotations = page->annotations();
+    const QList<Okular::Annotation *> annotations = page->annotations();
     for (Okular::Annotation *annotation : annotations) {
         if (annotation->subType() == Okular::Annotation::AScreen) {
             Okular::ScreenAnnotation *screenAnnotation = static_cast<Okular::ScreenAnnotation *>(annotation);
@@ -1296,7 +1294,7 @@ void PDFGenerator::resolveMediaLinkReferences(Okular::Page *page)
         }
     }
 
-    const QLinkedList<Okular::FormField *> fields = page->formFields();
+    const QList<Okular::FormField *> fields = page->formFields();
     for (Okular::FormField *field : fields) {
         resolveMediaLinkReference(field->activationAction());
     }
@@ -1357,7 +1355,7 @@ QByteArray PDFGenerator::requestFontData(const Okular::FontInfo &font)
     return pdfdoc->fontData(fi);
 }
 
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
 void PDFGenerator::okularToPoppler(const Okular::NewSignatureData &oData, Poppler::PDFConverter::NewSignatureData *pData)
 {
     pData->setCertNickname(oData.certNickname());
@@ -1365,14 +1363,14 @@ void PDFGenerator::okularToPoppler(const Okular::NewSignatureData &oData, Popple
     pData->setPage(oData.page());
     const QString datetime = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss t"));
     pData->setSignatureText(i18n("Signed by: %1\n\nDate: %2", oData.certSubjectCommonName(), datetime));
-#ifdef HAVE_POPPLER_FANCY_SIGNATURE
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 6, 0)
     pData->setSignatureLeftText(oData.certSubjectCommonName());
 #endif
     const Okular::NormalizedRect bRect = oData.boundingRectangle();
     pData->setBoundingRectangle({bRect.left, bRect.top, bRect.width(), bRect.height()});
     pData->setFontColor(Qt::black);
     pData->setBorderColor(Qt::black);
-#ifdef HAVE_POPPLER_22_02
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(22, 2, 0)
     pData->setDocumentOwnerPassword(oData.documentPassword().toLatin1());
     pData->setDocumentUserPassword(oData.documentPassword().toLatin1());
 #endif
@@ -1572,10 +1570,10 @@ QVariant PDFGenerator::metaData(const QString &key, const QVariant &option) cons
         if (Poppler::Version::string() == QStringLiteral(POPPLER_VERSION)) {
             return i18n("Using Poppler %1", Poppler::Version::string());
         } else {
-            return i18n("Using Poppler %1\n\nBuilt against Poppler %2", Poppler::Version::string(), POPPLER_VERSION);
+            return i18n("Using Poppler %1\n\nBuilt against Poppler %2", Poppler::Version::string(), QStringLiteral(POPPLER_VERSION));
         }
     } else if (key == QLatin1String("ShowStampsWarning")) {
-#ifdef HAVE_POPPLER_21_10
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 10, 0)
         return QStringLiteral("no");
 #else
         return QStringLiteral("yes");
@@ -1583,7 +1581,7 @@ QVariant PDFGenerator::metaData(const QString &key, const QVariant &option) cons
     } else if (key == QLatin1String("DocumentHasPassword")) {
         return pdfdoc->isEncrypted() ? QStringLiteral("yes") : QStringLiteral("no");
     } else if (key == QLatin1String("CanSignDocumentWithPassword")) {
-#ifdef HAVE_POPPLER_22_02
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(22, 2, 0)
         return QStringLiteral("yes");
 #else
         return QStringLiteral("no");
@@ -1913,14 +1911,14 @@ void PDFGenerator::addTransition(Poppler::Page *pdfPage, Okular::Page *page)
     page->setTransition(transition);
 }
 
-QLinkedList<Okular::FormField *> PDFGenerator::getFormFields(Poppler::Page *popplerPage)
+QList<Okular::FormField *> PDFGenerator::getFormFields(Poppler::Page *popplerPage)
 {
     if (!popplerPage) {
         return {};
     }
 
     const QList<Poppler::FormField *> popplerFormFields = popplerPage->formFields();
-    QLinkedList<Okular::FormField *> okularFormFields;
+    QList<Okular::FormField *> okularFormFields;
     for (Poppler::FormField *f : popplerFormFields) {
         Okular::FormField *of = nullptr;
         switch (f->type()) {
@@ -2019,7 +2017,7 @@ Okular::AnnotationProxy *PDFGenerator::annotationProxy() const
 
 bool PDFGenerator::canSign() const
 {
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     return Poppler::hasNSSSupport();
 #else
     return false;
@@ -2028,7 +2026,7 @@ bool PDFGenerator::canSign() const
 
 bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rFilename)
 {
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     // save to tmp file - poppler doesn't like overwriting in-place
     QTemporaryFile tf(QFileInfo(rFilename).absolutePath() + QLatin1String("/okular_XXXXXX.pdf"));
     tf.setAutoRemove(false);
@@ -2042,6 +2040,7 @@ bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rF
     Poppler::PDFConverter::NewSignatureData pData;
     okularToPoppler(oData, &pData);
     if (!converter->sign(pData)) {
+        tf.remove();
         return false;
     }
 
@@ -2061,7 +2060,7 @@ bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rF
 
 Okular::CertificateStore *PDFGenerator::certificateStore() const
 {
-#ifdef HAVE_POPPLER_SIGNING
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(21, 1, 0)
     if (!certStore) {
         certStore = new PopplerCertificateStore();
     }
@@ -2077,7 +2076,7 @@ void PDFGenerator::xrefReconstructionHandler()
     if (!xrefReconstructed) {
         qCDebug(OkularPdfDebug) << "XRef Table of the document has been reconstructed";
         xrefReconstructed = true;
-        emit warning(i18n("Some errors were found in the document, Okular might not be able to show the content correctly"), 5000);
+        Q_EMIT warning(i18n("Some errors were found in the document, Okular might not be able to show the content correctly"), 5000);
     }
 }
 
