@@ -42,10 +42,10 @@ public:
     void setTextToolsEnabled(bool on);
     void deselectAllAnnotationActions();
 
-signals:
+Q_SIGNALS:
     void ephemeralStampWarning();
 
-private slots:
+private Q_SLOTS:
     void slotAnnotationToolBarVisibilityChanged(bool visible);
 
 private:
