@@ -62,11 +62,11 @@ void Layers::notifySetup(const QVector<Okular::Page *> & /*pages*/, int /*setupF
     if (layersModel) {
         m_treeView->setModel(layersModel);
         m_searchLine->setTreeView(m_treeView);
-        emit hasLayers(true);
+        Q_EMIT hasLayers(true);
         connect(layersModel, &QAbstractItemModel::dataChanged, m_document, &Okular::Document::reloadDocument);
         connect(layersModel, &QAbstractItemModel::dataChanged, m_pageView, &PageView::reloadForms);
     } else {
-        emit hasLayers(false);
+        Q_EMIT hasLayers(false);
     }
 }
 
