@@ -17,9 +17,6 @@ public:
     explicit PageItemDelegate(QObject *parent = nullptr);
     ~PageItemDelegate() override;
 
-    static const int PageRole = 0x000f0001;
-    static const int PageLabelRole = 0x000f0002;
-
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
 protected:
